import numpy as np
import torch
import matplotlib.pyplot as plt
import torch.nn as nn
import torch.nn.functional as F
import cv2 as cv
import torchvision
from torchsummary import summary

# https://www.robots.ox.ac.uk/~vgg/research/very_deep/

# 3x 3x3 vs. 1x 7x7
class Block3x3x3Example(nn.Module):
    def __init__(self, in_channels, out_channels):
        super().__init__()
        self.conv1 = nn.Conv2d(in_channels, out_channels, kernel_size=3, padding=1, bias=False)
        self.conv2 = nn.Conv2d(out_channels, out_channels, kernel_size=3, padding=1, bias=False)
        self.conv3 = nn.Conv2d(out_channels, out_channels, kernel_size=3, padding=1, bias=False)

    def forward(self, X):
        out = self.conv1(X)
        out = self.conv2(out)
        out = self.conv3(out)
        return out

print("------------Block 3x 3x3 Example-----------------")
block_333 = Block3x3x3Example(32, 32)
summary(block_333, (32, 28, 28))

class Block1x7x7Example(nn.Module):
    def __init__(self, in_channels, out_channels):
        super().__init__()
        self.conv1 = nn.Conv2d(in_channels, out_channels, kernel_size=7, padding=3, bias=False)

    def forward(self, X):
        out = self.conv1(X)
        return out

print("------------Block 1x 7x7 Example-----------------")
block_177 = Block1x7x7Example(32, 32)
summary(block_177, (32, 28, 28))
